#!/usr/bin/env python
# encoding: utf-8

from dash.dependencies import Input, Output
from dash.exceptions import PreventUpdate
import dash_table
import json
import pandas as pd

from ...app import app
from .models import get_tribes, get_exams, get_scores


@app.callback(
    [
        Output("exam_select", "options"),
        Output("exam_select", "value"),
    ],
    [Input("tribe", "value")],
)
def update_exams_choices(value):
    if not value:
        raise PreventUpdate
    exams = get_exams(value)
    exams.reset_index(inplace=True)
    if not exams.empty:
        return [
            {"label": e["name"], "value": e.to_json()} for i, e in exams.iterrows()
        ], exams.loc[0].to_json()
    return [], None

@app.callback(
        [Output("scores", "data")],
        [Input("exam_select", "value")]
        )
def update_scores_store(value):
    if not value:
        return [[]]
    exam = pd.DataFrame.from_dict([json.loads(value)])
    return [get_scores(exam)]




# @app.callback(
#     [
#         Output("final_score", "data"),
#     ],
#     [Input("scores_table", "data")],
# )
# def update_final_scores(data):
#     if not data:
#         raise PreventUpdate
# 
#     scores = pd.DataFrame.from_records(data)
#     try:
#         if scores.iloc[0]["Commentaire"] == "commentaire":
#             scores.drop([0], inplace=True)
#     except KeyError:
#         pass
#     scores = flat_df_students(scores).dropna(subset=["Score"])
#     if scores.empty:
#         return [{}]
# 
#     scores = pp_q_scores(scores)
#     assessment_scores = scores.groupby(["Eleve"]).agg({"Note": "sum", "Bareme": "sum"})
#     return [assessment_scores.reset_index().to_dict("records")]
